Copy point style from matching antigens and sera in another acmap
applyPlotspec(map, source_map)Returns the acmap object with updated point styles (unmatched point styles unchanged)
Other map point style functions:
ptDrawingOrder(),
ptOpacity,
ptStyles