mapDescription: Getting and setting the map description

View source: R/map_props.R

mapDescriptionR Documentation

Getting and setting the map description

Description

Getting and setting the map description

Usage

mapDescription(map)
mapDescription(map) <- value

Arguments

map

The acmap data object

value

New value to set

Value

Returns either the requested attribute when using a getter function or

the updated acmap object when using the setter function.

See Also

Other map attribute functions: acmapAttributes, adjustedLogTiterTable(), adjustedTiterTable(), dilutionStepsize(), logtiterTableLayers(), mapName(), titerTableFlat(), titerTableLayers(), titerTable()


Racmacs documentation built on July 8, 2026, 9:06 a.m.