These functions attempt to estimate leverage of each antigen, sera or titer
by removing it from the data, relaxing the map, then calculating the rmsd of
the procrustes comparison between the original and newly relaxed map. Column
bases will be recalculated unless you have specified them as fixed with
fixedColBases().
agLeverage(map, antigens = TRUE, sera = TRUE)
srLeverage(map, antigens = TRUE, sera = TRUE)
titerLeverage(map, antigens = TRUE, sera = TRUE)Returns a numeric vector of the leverage calculated for each of the points.
Other map diagnostic functions:
agCohesion(),
bootstrapBlobs(),
bootstrapMap(),
checkHemisphering(),
dimensionTestMap(),
logtiterTable(),
map-table-distances,
mapBootstrapCoords,
mapDistances(),
mapRelaxed(),
mapResiduals(),
pointStress,
ptBootstrapBlob,
ptBootstrapCoords(),
ptTriangulationBlob,
recalculateStress(),
stressTable(),
tableColbases(),
tableDistances(),
triangulationBlobs(),
unstableMaps