Moves map coordinates back into random starting conditions, as performed
before each optimization run. The maximum table distance is calculated
then points are randomized in a box with side length equal to maximum
table distance multiplied by table_dist_factor
randomizeCoords(map, optimization_number = 1, table_dist_factor = 2)Returns an updated map object
Other map optimization functions:
RacOptimizer.options(),
make.acmap(),
moveTrappedPoints(),
optimizeMap(),
relaxMapOneStep(),
relaxMap()