Realigns all map optimizations through rotation and translation to match point positions as closely as possible to the first optimization run. This is done by default when optimizing a map and makes comparing point positions in each optimization run much easier to do by eye.
realignOptimizations(map)Returns the map with realigned optimizations
Other functions to compare maps:
matchStrains,
procrustesData(),
procrustesMap(),
realignMap()