Saves titer data of all or specified antigens and sera to a .csv file.
save.titerTable(map, filename, antigens = TRUE, sera = TRUE)No return value, called for the side effect of saving the titer data to the file.
Other functions for working with map data:
acmap(),
addOptimization(),
agReactivityAdjustments(),
as.json(),
edit_agNames(),
edit_srNames(),
keepBestOptimization(),
keepSingleOptimization(),
layerNames(),
orderPoints,
read.acmap(),
read.titerTable(),
removePoints,
save.acmap(),
save.coords(),
subsetCommonPoints,
subsetMap()